instance_types

package
v1.79.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

const RegionNameUsChi1 = shared.RegionNameUsChi1

Equals "us-chi-1"

const RegionNameUsSva1 = shared.RegionNameUsSva1

Equals "us-sva-1"

const RegionNameUsSva2 = shared.RegionNameUsSva2

Equals "us-sva-2"

const ResourceStatusCreating = shared.ResourceStatusCreating

Equals "creating"

const ResourceStatusDeleted = shared.ResourceStatusDeleted

Equals "deleted"

const ResourceStatusDeleting = shared.ResourceStatusDeleting

Equals "deleting"

const ResourceStatusError = shared.ResourceStatusError

Equals "error"

const ResourceStatusPending = shared.ResourceStatusPending

Equals "pending"

const ResourceStatusReady = shared.ResourceStatusReady

Equals "ready"

const ResourceStatusUpdating = shared.ResourceStatusUpdating

Equals "updating"

Variables

This section is empty.

Functions

This section is empty.

Types

type Error

type Error = apierror.Error

type InstanceType added in v1.64.0

type InstanceType struct {
	Chipset string `json:"chipset" api:"required"`
	// When the Instance Type was created.
	CreatedAt time.Time `json:"created_at" api:"required" format:"date-time"`
	Family    string    `json:"family" api:"required"`
	MemoryGB  int64     `json:"memory_gb" api:"required"`
	Name      string    `json:"name" api:"required"`
	// Network bandwidth in Gbps.
	NetworkBandwidthGbps float64 `json:"network_bandwidth_gbps" api:"required"`
	// Region the resource is in.
	//
	// Any of "us-sva-1", "us-sva-2", "us-chi-1".
	Region shared.RegionName `json:"region" api:"required"`
	Series string            `json:"series" api:"required"`
	// When the Instance Type was updated.
	UpdatedAt time.Time `json:"updated_at" api:"required" format:"date-time"`
	Vcpu      int64     `json:"vcpu" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Chipset              respjson.Field
		CreatedAt            respjson.Field
		Family               respjson.Field
		MemoryGB             respjson.Field
		Name                 respjson.Field
		NetworkBandwidthGbps respjson.Field
		Region               respjson.Field
		Series               respjson.Field
		UpdatedAt            respjson.Field
		Vcpu                 respjson.Field
		ExtraFields          map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

Instance type.

func (InstanceType) RawJSON added in v1.64.0

func (r InstanceType) RawJSON() string

Returns the unmodified JSON received from the API

func (*InstanceType) UnmarshalJSON added in v1.64.0

func (r *InstanceType) UnmarshalJSON(data []byte) error

type InstanceTypeGetParamsRegion added in v1.64.0

type InstanceTypeGetParamsRegion string
const (
	InstanceTypeGetParamsRegionUsSva1 InstanceTypeGetParamsRegion = "us-sva-1"
	InstanceTypeGetParamsRegionUsSva2 InstanceTypeGetParamsRegion = "us-sva-2"
	InstanceTypeGetParamsRegionUsChi1 InstanceTypeGetParamsRegion = "us-chi-1"
)

type InstanceTypeList

type InstanceTypeList struct {
	Items []InstanceType `json:"items" api:"required"`
	// Pagination response details.
	Pagination shared.Pagination `json:"pagination" api:"required"`
	// JSON contains metadata for fields, check presence with [respjson.Field.Valid].
	JSON struct {
		Items       respjson.Field
		Pagination  respjson.Field
		ExtraFields map[string]respjson.Field
		// contains filtered or unexported fields
	} `json:"-"`
}

func (InstanceTypeList) RawJSON

func (r InstanceTypeList) RawJSON() string

Returns the unmodified JSON received from the API

func (*InstanceTypeList) UnmarshalJSON

func (r *InstanceTypeList) UnmarshalJSON(data []byte) error

type InstanceTypeListParams

type InstanceTypeListParams struct {
	// Pagination cursor returned by a previous request
	Cursor param.Opt[string] `query:"cursor,omitzero" json:"-"`
	// Maximum number of items to return
	Limit param.Opt[int64] `query:"limit,omitzero" json:"-"`
	// contains filtered or unexported fields
}

func (InstanceTypeListParams) URLQuery

func (r InstanceTypeListParams) URLQuery() (v url.Values, err error)

URLQuery serializes InstanceTypeListParams's query parameters as `url.Values`.

type InstanceTypeService

type InstanceTypeService struct {
	Options []option.RequestOption
}

InstanceTypeService contains methods and other services that help with interacting with the Nirvana Labs API.

Note, unlike clients, this service does not read variables from the environment automatically. You should not instantiate this service directly, and instead use the NewInstanceTypeService method instead.

func NewInstanceTypeService

func NewInstanceTypeService(opts ...option.RequestOption) (r InstanceTypeService)

NewInstanceTypeService generates a new service that applies the given options to each request. These options are applied after the parent client's options (if there is one), and before any request-specific options.

func (*InstanceTypeService) Get added in v1.64.0

Get an instance type by region and name

func (*InstanceTypeService) List

List instance types

func (*InstanceTypeService) ListAutoPaging

List instance types

type Pagination

type Pagination = shared.Pagination

Pagination response details.

This is an alias to an internal type.

type RegionName

type RegionName = shared.RegionName

Region the resource is in.

This is an alias to an internal type.

type ResourceStatus

type ResourceStatus = shared.ResourceStatus

Status of the resource.

This is an alias to an internal type.

type SourceIPRuleParam

type SourceIPRuleParam = shared.SourceIPRuleParam

IP filter rules.

This is an alias to an internal type.

type SourceIPRuleResponse

type SourceIPRuleResponse = shared.SourceIPRuleResponse

IP filter rules.

This is an alias to an internal type.

Jump to